@@ -4,16 +4,16 @@
  *         http://www.frankylam.com/
  *
  */
-#include <gkrellm/gkrellm.h>
+#include <gkrellm2/gkrellm.h>
 
-#define GKRELLWEATHER_VERSION   "0.2.7"
 #define DEFAULT_STATION_ID      "YSSY"
 
+#define STYLE_NAME      "weather"
+
 /*    net update status    */
 static gboolean    net_update;
 
-static gint     cal_style_id,
-                clock_style_id;
+static gint style_id;
 
 enum {  TEM_DISPLAY = 0,
         DEW_DISPLAY = 1,
@@ -25,16 +25,18 @@ enum {  TEM_DISPLAY = 0,
 
 static gint     panel_state = 0;
 static gint     x_scroll = 0;
+static gint     name_xoff = 0;
+static gint     sky_cond_xoff = 0;
 
-static Chart    *chart;     /* for later release    */
-static Panel    *panel;
-static Style    *style;
-static Decal    *decal_temperature,     *decal_unit1,
-                *decal_humidity,        *decal_unit2,
-                *decal_dew_point,       *decal_wind_chill,
-                *decal_wind_direction,  *decal_wind_speed,
-                *decal_pressure,
-                *decal_name,            *decal_sky_cond;
+static GkrellmChart    *chart;
+static GkrellmMonitor  *monitor;
+static GkrellmPanel    *panel;
+static GkrellmDecal    *decal_temperature,     *decal_unit1,
+    *decal_humidity,        *decal_unit2,
+    *decal_dew_point,       *decal_wind_chill,
+    *decal_wind_direction,  *decal_wind_speed,
+    *decal_pressure,
+    *decal_name,            *decal_sky_cond;
 
 static GtkWidget    *metric_option,
                     *km_per_hour_option,
@@ -52,12 +54,12 @@ static gchar        *weather_tips_text;
 
 typedef struct
 {
-    TextStyle   ts;
-    gint        lbearing,
-                rbearing,
-                width,
-                ascent,
-                descent;
+    GkrellmTextstyle   ts;
+    gint lbearing,
+	rbearing,
+	width,
+	ascent,
+	descent;
 }
 Extents;
 
@@ -121,12 +123,18 @@ read_air ()
     static gint i, cursize, spd, scale[] =
     { 1, 3, 4, 10, 16, 21, 27, 33, 40, 47, 55, 63, 71 };
     FILE *fp;
+    char *oldlocale;
 
+    // decimal point stuff
+    oldlocale = g_strdup(setlocale(LC_NUMERIC, NULL));
+    setlocale(LC_NUMERIC, "C");
     if ((fp = fopen(options.filename, "r")) != NULL) {
         fgets(air.name, 512, fp);
         if (air.name[0] == '\0' || air.name[0] == '\n')
         {   /* GrabWeather could not read data from server */
             fclose(fp);
+	    setlocale(LC_NUMERIC, oldlocale);
+	    g_free(oldlocale);
             return FALSE;
         }
         for (c = air.name; *c && *c != '('; c++); /* extract name */
@@ -146,6 +154,9 @@ read_air ()
         else {
             air.sky_cond_avail = 1;
         }
+	if (air.sky_cond[strlen(air.sky_cond)-1] == '\n') 
+	    air.sky_cond[strlen(air.sky_cond)-1] = '\0';
+	
 
         fgets(line, 512, fp);
 
@@ -182,6 +193,11 @@ read_air ()
         air.wind_direction  = -99.0;
         air.wind_speed[0]   = -99.0;
     }
+    setlocale(LC_NUMERIC, oldlocale);
+    g_free(oldlocale);
+
+    name_xoff = -gdk_string_width(gkrellm_default_font(1), air.name);
+    sky_cond_xoff = -gdk_string_width(gkrellm_default_font(1), air.sky_cond);
 
     // Change tooltips
     if (weather_tips != NULL)
@@ -241,10 +257,10 @@ calc_xy (gint i)
     default:
         w = decal_temperature->w + decal_unit1->w + decal_humidity->w +
             decal_unit2->w;
-        decal_temperature->x = (gkrellm_chart_width() - w + 1) / 2 + 1;
+        decal_temperature->x = -1;
         decal_unit1->x = decal_temperature->x + decal_temperature->w - 1;
-        decal_humidity->x = decal_unit1->x + decal_unit1->w + 1;
-        decal_unit2->x = decal_humidity->x + decal_humidity->w - 1;
+        decal_unit2->x = gkrellm_chart_width() - decal_unit2->w - 1;
+        decal_humidity->x = decal_unit2->x - decal_humidity->w;
         break;
     }
 }
@@ -270,15 +286,21 @@ draw_panel ()
     switch (panel_state) {
         case NAM_DISPLAY:
             w = gkrellm_chart_width();
-            x_scroll = (x_scroll + 1) % (2 * w);
-            decal_name->x_off = w - x_scroll;
+	    if (x_scroll > name_xoff)
+		x_scroll -= 2;
+	    else
+		x_scroll = w;
+            decal_name->x_off = x_scroll;
             gkrellm_draw_decal_text(panel, decal_name, air.name, w - x_scroll);
             break;
         case SKY_DISPLAY:
             if (air.sky_cond_avail) {
                 w = gkrellm_chart_width();
-                x_scroll = (x_scroll + 1) % (2 * w);
-                decal_sky_cond->x_off = w - x_scroll;
+		if (x_scroll > sky_cond_xoff)
+		    x_scroll -= 2;
+		else
+		    x_scroll = w;
+		decal_sky_cond->x_off = x_scroll;
                 gkrellm_draw_decal_text(panel, decal_sky_cond, air.sky_cond,
                         w - x_scroll);
             }
@@ -439,7 +461,7 @@ update_air ()
         run_command();
     }
     draw_panel();
-    gkrellm_draw_layers(panel);
+    gkrellm_draw_panel_layers(panel);
 }
 
 
@@ -480,6 +502,7 @@ panel_press (GtkWidget *widget, GdkEventButton *ev)
 static void
 create_air (GtkWidget *vbox, gint first_create)
 {
+    GkrellmStyle *style;
     gint i;
 
     if (first_create)
@@ -493,29 +516,31 @@ create_air (GtkWidget *vbox, gint first_create)
         gkrellm_destroy_decal_list(panel);
     }
 
-    panel->textstyle = gkrellm_meter_textstyle(cal_style_id);
+    style = gkrellm_meter_style(style_id);
 
-    ext_temperature.ts = *gkrellm_meter_alt_textstyle(clock_style_id);
+    panel->textstyle = gkrellm_meter_alt_textstyle(style_id);
+
+    ext_temperature.ts = *gkrellm_meter_alt_textstyle(style_id);
     string_extents("+888", &ext_temperature);
-    ext_unit1.ts = *gkrellm_meter_textstyle(cal_style_id);
+    ext_unit1.ts = *gkrellm_meter_textstyle(style_id);
     string_extents("C", &ext_unit1);
-    ext_humidity.ts = *gkrellm_meter_alt_textstyle(clock_style_id);
+    ext_humidity.ts = *gkrellm_meter_alt_textstyle(style_id);
     string_extents("88", &ext_humidity);
-    ext_unit2.ts = *gkrellm_meter_textstyle(cal_style_id);
+    ext_unit2.ts = *gkrellm_meter_textstyle(style_id);
     string_extents("%", &ext_unit2);
-    ext_dew_point.ts = *gkrellm_meter_alt_textstyle(clock_style_id);
+    ext_dew_point.ts = *gkrellm_meter_alt_textstyle(style_id);
     string_extents("+888", &ext_dew_point);
-    ext_wind_chill.ts = *gkrellm_meter_alt_textstyle(clock_style_id);
+    ext_wind_chill.ts = *gkrellm_meter_alt_textstyle(style_id);
     string_extents("+888", &ext_wind_chill);
-    ext_pressure.ts = *gkrellm_meter_alt_textstyle(clock_style_id);
+    ext_pressure.ts = *gkrellm_meter_alt_textstyle(style_id);
     string_extents("8888", &ext_pressure);
-    ext_wind_direction.ts = *gkrellm_meter_textstyle(cal_style_id);
+    ext_wind_direction.ts = *gkrellm_meter_textstyle(style_id);
     string_extents("WWW", &ext_wind_direction);
-    ext_wind_speed.ts = *gkrellm_meter_alt_textstyle(clock_style_id);
+    ext_wind_speed.ts = *gkrellm_meter_alt_textstyle(style_id);
     string_extents("888", &ext_wind_speed);
-    ext_name.ts = *gkrellm_meter_alt_textstyle(clock_style_id);
+    ext_name.ts = *gkrellm_meter_alt_textstyle(style_id);
     string_extents("Ay", &ext_name);
-    ext_sky_cond.ts = *gkrellm_meter_alt_textstyle(clock_style_id);
+    ext_sky_cond.ts = *gkrellm_meter_alt_textstyle(style_id);
     string_extents("Ay", &ext_sky_cond);
 
     decal_temperature = gkrellm_create_decal_text(panel, "+888",
@@ -523,7 +548,7 @@ create_air (GtkWidget *vbox, gint first_create)
     decal_unit1 = gkrellm_create_decal_text(panel, "C", &ext_unit1.ts,
             style, 0, 3, ext_unit1.width + 2);
     decal_humidity = gkrellm_create_decal_text(panel, "88", &ext_humidity.ts,
-            style, 0, 3, ext_humidity.width + 2);
+            style, 0, 3, ext_humidity.width + 4);
     decal_unit2 = gkrellm_create_decal_text(panel, "%", &ext_unit2.ts,
             style, 0, 3, ext_unit2.width + 2);
     decal_dew_point = gkrellm_create_decal_text(panel, "+888",
@@ -569,12 +594,12 @@ create_air (GtkWidget *vbox, gint first_create)
     decal_humidity->y = decal_wind_speed->y = decal_temperature->y;
     decal_wind_direction->y = decal_wind_speed->y + decal_wind_speed->h -
         decal_wind_direction->h;
-    gkrellm_configure_panel(panel, NULL, gkrellm_meter_style(cal_style_id));
-    gkrellm_create_panel(vbox, panel, gkrellm_bg_meter_image(cal_style_id));
-    chart->h = 36;
+    gkrellm_panel_configure(panel, NULL, gkrellm_meter_style(style_id));
+    gkrellm_panel_create(vbox, monitor, panel);
+//    chart->h = 36;
     /* gkrellm_create_chart(vbox, chart, DEFAULT_STYLE); */
     /* gkrellm_monitor_height_adjust(chart->h + panel->h); */
-    gkrellm_monitor_height_adjust(panel->h);
+//    gkrellm_monitor_height_adjust(panel->h);
 
     if (weather_tips == NULL)
     {
@@ -687,19 +712,21 @@ apply_air_config (void)
     if (old_metric != options.metric)
     {
         draw_panel();
-        gkrellm_draw_layers(panel);
+        gkrellm_draw_panel_layers(panel);
     }
-    c = gtk_entry_get_text(GTK_ENTRY(station_option));
+    c = g_strdup(gtk_entry_get_text(GTK_ENTRY(station_option)));
     if (strcmp(options.station, c)) {
         options.station[0] = c[0];
         options.station[1] = c[1];
         options.station[2] = c[2];
         options.station[3] = c[3];
-        sprintf(options.command, "GrabWeather %s", options.station);
+        sprintf(options.command, PREFIX "/bin/GrabWeather %s", options.station);
         sprintf(options.filename, "%s/.wmWeatherReports/%s.dat",
                 getenv("HOME"), options.station);
-        run_command();
+	net_update = FALSE;
+	run_command();
     }
+    g_free(c);
     options.update_interval = gtk_spin_button_get_value_as_int(
             GTK_SPIN_BUTTON(update_interval_option));
     options.switch_interval = gtk_spin_button_get_value_as_int(
@@ -710,7 +737,7 @@ static void windspeed_unit_set(GtkWidget *w, gpointer data)
 {
     options.windspeed_unit = GPOINTER_TO_INT(data);
     draw_panel();
-    gkrellm_draw_layers(panel);
+    gkrellm_draw_panel_layers(panel);
 }
 
 
@@ -718,7 +745,7 @@ static void pressure_unit_set(GtkWidget *w, gpointer data)
 {
     options.pressure_unit = GPOINTER_TO_INT(data);
     draw_panel();
-    gkrellm_draw_layers(panel);
+    gkrellm_draw_panel_layers(panel);
 }
 
 static void
@@ -730,9 +757,10 @@ create_air_tab (GtkWidget *tab)
     GSList  *wind_speed_group = NULL,
             *pressure_group = NULL;
     gchar *about_text = NULL;
+    gint i;
     static gchar *help_text[] =
     {
-        "GKrellWeather shows the current weather under the clock.\n" \
+        N_("GKrellWeather shows the current weather under the clock.\n" \
         "\n" \
         "Right click the panel to toggle between different display:\n" \
         "\n" \
@@ -744,9 +772,9 @@ create_air_tab (GtkWidget *tab)
         "\n" \
         "Options:\n" \
         " switch interval - number of seconds (0 = never)" \
-        " between switching display\n"
+        " between switching display\n")
     };
-    static gchar url[] = "http://www.nws.noaa.gov/oso/siteloc.shtml";
+    static gchar url[] = "http://www.nws.noaa.gov/tg/siteloc.shtml";
     laptop = gtk_notebook_new();
     gtk_notebook_set_tab_pos(GTK_NOTEBOOK(laptop), GTK_POS_TOP);
     gtk_box_pack_start(GTK_BOX(tab), laptop, TRUE, TRUE, 0);
@@ -759,7 +787,7 @@ create_air_tab (GtkWidget *tab)
     gtk_container_border_width(GTK_CONTAINER(vbox), 3);
 
     hbox = gtk_hbox_new(FALSE, 0);
-    label = gtk_label_new("4 letter Station ID:");
+    label = gtk_label_new(_("4 letter Station ID:"));
     station_option = gtk_entry_new_with_max_length(8);
     gtk_entry_set_text(GTK_ENTRY(station_option), options.station);
     gtk_entry_set_editable(GTK_ENTRY(station_option), TRUE);
@@ -768,7 +796,7 @@ create_air_tab (GtkWidget *tab)
     gtk_container_add(GTK_CONTAINER(vbox), hbox);
 
     hbox = gtk_hbox_new(FALSE, 0);
-    label = gtk_label_new("Get your station ID at:");
+    label = gtk_label_new(_("Get your station ID at:"));
     url_option = gtk_entry_new_with_max_length(64);
     gtk_entry_set_text(GTK_ENTRY(url_option), url);
     gtk_entry_set_editable(GTK_ENTRY(url_option), FALSE);
@@ -779,7 +807,7 @@ create_air_tab (GtkWidget *tab)
     hbox = gtk_hbox_new(FALSE, 0);
     /* check boxes */
     zbox = gtk_vbox_new(FALSE, 0);
-    metric_option = gtk_check_button_new_with_label("Display in metric unit");
+    metric_option = gtk_check_button_new_with_label(_("Display in metric unit"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(metric_option),
             options.metric);
     gtk_container_add(GTK_CONTAINER(zbox), metric_option);
@@ -793,7 +821,7 @@ create_air_tab (GtkWidget *tab)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(switch_interval_option),
             options.switch_interval);
     gtk_box_pack_start(GTK_BOX(ybox), switch_interval_option, FALSE, FALSE, 0);
-    label = gtk_label_new("switch interval (secs)");
+    label = gtk_label_new(_("switch interval (secs)"));
     gtk_box_pack_start(GTK_BOX(ybox), label, FALSE, FALSE, 0);
     gtk_container_add(GTK_CONTAINER(zbox), ybox);
 
@@ -806,7 +834,7 @@ create_air_tab (GtkWidget *tab)
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(update_interval_option),
             options.update_interval);
     gtk_box_pack_start(GTK_BOX(ybox), update_interval_option, FALSE, FALSE, 0);
-    label = gtk_label_new("update interval (mins)");
+    label = gtk_label_new(_("update interval (mins)"));
     gtk_box_pack_start(GTK_BOX(ybox), label, FALSE, FALSE, 0);
     gtk_container_add(GTK_CONTAINER(zbox), ybox);
 
@@ -814,10 +842,10 @@ create_air_tab (GtkWidget *tab)
 
     /* windspeed radio buttons */
     zbox = gtk_vbox_new(FALSE, 0);
-    label = gtk_label_new("metric windspeed unit:");
+    label = gtk_label_new(_("metric windspeed unit:"));
     gtk_container_add(GTK_CONTAINER(zbox), label);
 
-    km_per_hour_option = gtk_radio_button_new_with_label(NULL, "km/h");
+    km_per_hour_option = gtk_radio_button_new_with_label(NULL, _("km/h"));
     wind_speed_group = gtk_radio_button_group(
             GTK_RADIO_BUTTON(km_per_hour_option));
     gtk_container_add(GTK_CONTAINER(zbox), km_per_hour_option);
@@ -827,7 +855,7 @@ create_air_tab (GtkWidget *tab)
         (GtkSignalFunc) windspeed_unit_set, GINT_TO_POINTER(1));
 
     meter_per_second_option = gtk_radio_button_new_with_label(wind_speed_group,
-            "m/s");
+            _("m/s"));
     wind_speed_group = gtk_radio_button_group(
             GTK_RADIO_BUTTON(meter_per_second_option));
     gtk_container_add(GTK_CONTAINER(zbox), meter_per_second_option);
@@ -837,7 +865,7 @@ create_air_tab (GtkWidget *tab)
         (GtkSignalFunc) windspeed_unit_set, GINT_TO_POINTER(2));
 
     beaufort_option = gtk_radio_button_new_with_label(wind_speed_group,
-            "beaufort");
+            _("beaufort"));
     gtk_container_add(GTK_CONTAINER(zbox), beaufort_option);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(beaufort_option),
         options.windspeed_unit == 3);
@@ -847,9 +875,9 @@ create_air_tab (GtkWidget *tab)
 
     /* pressure radio buttons */
     zbox = gtk_vbox_new(FALSE, 0);
-    label = gtk_label_new("metric pressure unit:");
+    label = gtk_label_new(_("metric pressure unit:"));
     gtk_container_add(GTK_CONTAINER(zbox), label);
-    mmHg_option = gtk_radio_button_new_with_label(NULL, "mmHg");
+    mmHg_option = gtk_radio_button_new_with_label(NULL, _("mmHg"));
     pressure_group = gtk_radio_button_group(GTK_RADIO_BUTTON(mmHg_option));
     gtk_container_add(GTK_CONTAINER(zbox), mmHg_option);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(mmHg_option),
@@ -857,7 +885,7 @@ create_air_tab (GtkWidget *tab)
     gtk_signal_connect(GTK_OBJECT(mmHg_option), "pressed",
         (GtkSignalFunc) pressure_unit_set, GINT_TO_POINTER(1));
 
-    kPa_option = gtk_radio_button_new_with_label(pressure_group, "kPa");
+    kPa_option = gtk_radio_button_new_with_label(pressure_group, _("kPa"));
     pressure_group = gtk_radio_button_group(GTK_RADIO_BUTTON(kPa_option));
     gtk_container_add(GTK_CONTAINER(zbox), kPa_option);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(kPa_option),
@@ -865,7 +893,7 @@ create_air_tab (GtkWidget *tab)
     gtk_signal_connect(GTK_OBJECT(kPa_option), "pressed",
         (GtkSignalFunc) pressure_unit_set, GINT_TO_POINTER(2));
 
-    hPa_option = gtk_radio_button_new_with_label(pressure_group, "hPa");
+    hPa_option = gtk_radio_button_new_with_label(pressure_group, _("hPa"));
     gtk_container_add(GTK_CONTAINER(zbox), hPa_option);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(hPa_option),
         options.pressure_unit == 3);
@@ -875,7 +903,7 @@ create_air_tab (GtkWidget *tab)
 
     gtk_container_add(GTK_CONTAINER(vbox), hbox);
 
-    label = gtk_label_new("Options");
+    label = gtk_label_new(_("Options"));
     gtk_container_add(GTK_CONTAINER(frame), vbox);
     gtk_notebook_append_page(GTK_NOTEBOOK(laptop), frame, label);
 
@@ -887,35 +915,35 @@ create_air_tab (GtkWidget *tab)
     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_container_add(GTK_CONTAINER(frame), info_window);
 
-    text = gtk_text_new(NULL, NULL);
+    text = gtk_text_view_new();
 
-    gkrellm_add_info_text(text, help_text, sizeof(help_text)/sizeof(gchar*));
-    gtk_text_set_editable(GTK_TEXT(text), FALSE);
+    for (i=0; i < sizeof(help_text)/sizeof(gchar *); ++i)
+      gkrellm_gtk_text_view_append(text, _(help_text[i]));
     gtk_container_add(GTK_CONTAINER(info_window), text);
 
-    label = gtk_label_new("Help");
+    label = gtk_label_new(_("Help"));
     gtk_notebook_append_page(GTK_NOTEBOOK(laptop), frame, label);
 
     /* about */
     about_text = g_strdup_printf(
-        "GKrellWeather %s\n" \
+        _("GKrellWeather %s\n" \
         "GKrellM weather Plugin\n" \
         "\n" \
         "Copyright (C) 2001 Franky Lam\n" \
         "franky@frankylam.com\n" \
         "http://www.frankylam.com/\n" \
         "\n" \
-        "Released under the GNU Public License\n" \
-        , GKRELLWEATHER_VERSION
+        "Released under the GNU Public License\n") \
+        , VERSION
     );
     about_label = gtk_label_new(about_text);
     g_free(about_text);
-    label = gtk_label_new("About");
+    label = gtk_label_new(_("About"));
     gtk_notebook_append_page(GTK_NOTEBOOK(laptop), about_label, label);
 }
 
 
-static Monitor air_mon =
+static GkrellmMonitor air_mon =
 {
     "GKrellWeather",    /* Name, for config tab.    */
     0,                  /* Id,  0 if a plugin       */
@@ -955,23 +983,24 @@ read_default(void)
     options.windspeed_unit = 1;
     options.pressure_unit = 1;
     strcpy(options.station, DEFAULT_STATION_ID);
-    sprintf(options.command, "GrabWeather %s", options.station);
+    sprintf(options.command, "/usr/share/gkrellm/GrabWeather %s", options.station);
     sprintf(options.filename, "%s/.wmWeatherReports/%s.dat",
             getenv("HOME"), options.station);
 }
 
 
-Monitor *
-init_plugin(void)
+GkrellmMonitor *
+gkrellm_init_plugin(void)
 {
-    style = gkrellm_panel_style(cal_style_id);
-
-    cal_style_id = gkrellm_lookup_meter_style_id(CAL_STYLE_NAME);
-    clock_style_id = gkrellm_lookup_meter_style_id(CLOCK_STYLE_NAME);
+    #ifdef ENABLE_NLS
+        bind_textdomain_codeset(PACKAGE, "UTF-8");
+    #endif /* ENABLE_NLS */
+    style_id = gkrellm_add_meter_style(&air_mon, STYLE_NAME);
 
     read_default();
-    run_command();
 
-    net_update = FALSE;    
+    net_update = FALSE;
+
+    monitor = &air_mon;
     return &air_mon;
 }
